@@ -19,9 +19,9 @@
 
 """The main module for the Orca screen reader."""
 
-__id__        = "$Id: orca.py 4285 2008-10-12 20:42:37Z wwalker $"
-__version__   = "$Revision: 4285 $"
-__date__      = "$Date: 2008-10-12 16:42:37 -0400 (Sun, 12 Oct 2008) $"
+__id__        = "$Id$"
+__version__   = "$Revision$"
+__date__      = "$Date$"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -56,7 +56,6 @@ except RuntimeError:
     pass
 
 import getopt
-import gnome
 import os
 import signal
 import time
@@ -1094,12 +1093,9 @@ def helpForOrca(script=None, inputEvent=None):
 
     Returns True to indicate the input event has been consumed.
     """
-
-    props = { gnome.PARAM_APP_DATADIR : '/usr/share'}
-    prog = gnome.program_init('orca', '1.0', properties=props)
-    gnome.help_display_with_doc_id(prog, 'gnome-access-guide',
-                                         'gnome-access-guide', 'ats-2')
-
+    gtk.show_uri(gtk.gdk.screen_get_default(),
+                 "ghelp:gnome-access-guide#ats-2",
+                 gtk.get_current_event_time())
     return True
 
 def quitOrca(script=None, inputEvent=None):
@@ -1226,7 +1222,7 @@ def start(registry):
     if settings.cacheValues:
         pyatspi.setCacheLevel(pyatspi.CACHE_PROPERTIES)
 
-    registry.start()
+    registry.start(gil=settings.useGILIdleHandler)
 
 def die(exitCode=1):
 
