@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "2.26.2"
+version     = "2.27.1"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/export/home/wwalker/work/orca/bld"
+prefix      = "/export/home/wwalker/Downloads/orca/bld"
 
 # The package name (should be "orca").
 #
